%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% File: displayResults.m
%
% Description: Displays the marginal product model, current best solution
% and its fitness value at the end of every generation
%
% @param gen is the current generation number
%
% @param mpm is the marginal product model 
%
% @param bestSolution is the best solution found so far during the eCGA run.
% 
% @param bestFit is the fitness of the current best solution.
%
% Author: Kumara Sastry
%
% Date: March 2007
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function displayResults(gen, mpm, bestSolution, bestFit)
    
% Print the model, best-so-far solution and its fitness
clear message;
message = sprintf('---End of generation # %d---', gen);
disp(message);

clear message;
message = sprintf('eCGA model: {');
model = mpm.SubStructures;
for i = 1:size(model,2),
    message = sprintf('%s [', message);
    clear message1;
    message1 = sprintf('%d ', model{i});
    message = sprintf('%s %s ]', message, message1);
end
message = sprintf('%s }', message);
disp(message);

clear message;
clear message1;
message = sprintf('Best solution: ');
message1 = sprintf('%d', bestSolution);
message = sprintf('%s %s', message, message1);
disp(message);

clear message;
message = sprintf('Maximum Fitness: %f', bestFit);
disp(message);

clear message;
message = sprintf('-----------------------------\n\n');
disp(message);
