%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% File: truncationSelection.m
%
% Description: Perform truncation selection and return the mating pool
% (index of selected individuals)
%
% @param truncParam is the selection pressure parameter
%
% @return winners is an array with the index of the individuals that won
% the tournaments.
%
% Author: Kumara Sastry
%
% Date: March 2007
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function winners = truncationSelection(truncParam, fitness)

n = length(fitness);
numWinners = floor(n*truncParam);
numCopies = ceil(1/truncParam);

[sortedFitness, index] = sort(fitness,'descend');
potentialWinners = repmat(index(1:numWinners),numCopies,1);
winners = potentialWinners(1:n);